#property link          "https://www.earnforex.com/metatrader-scripts/delete-all-pending/"
#property version       "1.00"
#property strict
#property copyright     "EarnForex.com - 2020-2021"
#property description   "This is a script to delete all the pending orders" 
#property description   " "
#property description   "WARNING : You use this software at your own risk."
#property description   "The creator of these plugins cannot be held responsible for any damage or loss."
#property description   " "
#property description   "Find More on EarnForex.com"
#property icon          "\\Files\\EF-Icon-64x64px.ico"
#property show_inputs

enum ENUM_ORDER_TYPES{
   ALL_ORDERS=1,        //ALL PENDING ORDERS
   ONLY_BUY_STOP=2,     //BUY STOP ONLY
   ONLY_BUY_LIMIT=3,    //BUY LIMIT ONLY
   ONLY_SELL_STOP=4,    //SELL STOP ONLY
   ONLY_SELL_LIMIT=5    //SELL LIMIT ONLY
};

input bool OnlyCurrentSymbol=false;   //Close only instrument in the chart
input ENUM_ORDER_TYPES OrderTypeFilter=ALL_ORDERS;     //Type of orders to delete
input string OrderCommentFilter="";    //Only close orders with this comment
input int OrderMagicFilter=0;          //Only close orders matching this magic number
input bool OnlyMagicNumber=false;     //Close only orders matching the magic number
input int MagicNumber=0;              //Matching magic number
input bool OnlyWithComment=false;     //Close only orders with the following comment
input string MatchingComment="";      //Matching comment
input int Delay=0;                    //Delay to wait between closing orders (in milliseconds)

void DeleteOrders(){
   
   //Log in the terminal the total of orders, current and past
   Print(OrdersTotal());
      
   //Start a loop to scan all the orders
   //The loop starts from the last otherwise it would miss orders
   for(int i=(OrdersTotal()-1);i>=0;i--){
      
      //If the order cannot be selected throw and log an error
      if(OrderSelect(i,SELECT_BY_POS,MODE_TRADES)==false){
         Print("ERROR - Unable to select the order - ",GetLastError());
         break;
      } 

      //check if the order matches the filter and if not skip the order and move to the next
      if(OrderTypeFilter==ONLY_SELL_LIMIT && OrderType()!=OP_SELLLIMIT) continue;   //don't action if the order type doesn't match
      if(OrderTypeFilter==ONLY_SELL_STOP && OrderType()!=OP_SELLSTOP) continue;     //don't action if the order type doesn't match
      if(OrderTypeFilter==ONLY_BUY_LIMIT && OrderType()!=OP_BUYLIMIT) continue;     //don't action if the order type doesn't match
      if(OrderTypeFilter==ONLY_BUY_STOP && OrderType()!=OP_BUYSTOP) continue;       //don't action if the order type doesn't match
      if(OnlyCurrentSymbol && OrderSymbol()!=Symbol()) continue;
      if(OnlyMagicNumber && OrderMagicNumber()!=MagicNumber) continue;
      if(OnlyWithComment && StringCompare(OrderComment(),MatchingComment)!=0) continue;
      //You could add additional filters like expiry or open price or so on
      
      //Create the required variables
      //Result variable, to check if the operation is successful or not
      bool res=false;
      
      //Deleting the order using the correct price depending on the type of order
      if(OrderType()==OP_BUYLIMIT || OrderType()==OP_BUYSTOP || OrderType()==OP_SELLLIMIT || OrderType()==OP_SELLSTOP){
         res=OrderDelete(OrderTicket());
      }
      
      //If there was an error log it
      if(res==false) Print("ERROR - Unable to delete the order - ",OrderTicket()," - ",GetLastError());

      Sleep(Delay);
   }
}


void OnStart(){

   //Call the function when the script is run
   DeleteOrders();

}